==> app_service-1.0.1.tar.gz: lib/src/maps/lang_enum_to_string_map.dart <==
import '../enums/language_enum.dart';

/// 语言枚举转字符串映射
/// - 用于获取服务内识别语言的字符串
/// - 此字符串多数情况下为直接可用于 Local 的字符串标识
final Map<LanguageEnum, String> languageEnumToStringMap = {
  LanguageEnum.zh: 'zh', // 中文
  LanguageEnum.zhHans: 'zh_Hans', // 简体中文
  LanguageEnum.zhHant: 'zh_Hant', // 繁体中文
  LanguageEnum.zhHk: 'zh_HK', // 中文（香港）
  LanguageEnum.zhTw: 'zh_TW', // 中文（台湾）
  LanguageEnum.ru: 'ru', // 俄语
  LanguageEnum.de: 'de', // 德语
  LanguageEnum.fr: 'fr', // 法语
  LanguageEnum.ja: 'ja', // 日语
  LanguageEnum.ko: 'ko', // 韩语
  LanguageEnum.es: 'es', // 西班牙语
  LanguageEnum.ar: 'ar', // 阿拉伯语
  LanguageEnum.en: 'en', // 英语
  LanguageEnum.enUs: 'US', // 英语（美国）
  LanguageEnum.enUk: 'UK', // 英语（英国）
  LanguageEnum.pt: 'pt', // 葡萄牙语
  LanguageEnum.it: 'it', // 意大利语
  LanguageEnum.nl: 'nl', // 荷兰语
  LanguageEnum.tr: 'tr', // 土耳其语
  LanguageEnum.hi: 'hi', // 印地语
  LanguageEnum.id: 'id', // 印度尼西亚语
  LanguageEnum.vi: 'vi', // 越南语
  LanguageEnum.th: 'th', // 泰语
  LanguageEnum.ms: 'ms', // 马来语
  LanguageEnum.fil: 'fil', // 菲律宾语
  LanguageEnum.sv: 'sv', // 瑞典语
  LanguageEnum.pl: 'pl', // 波兰语
  LanguageEnum.hu: 'hu', // 匈牙利语
  LanguageEnum.ro: 'ro', // 罗马尼亚语
  LanguageEnum.cs: 'cs', // 捷克语
  LanguageEnum.el: 'el', // 希腊语
  LanguageEnum.he: 'he', // 希伯来语
  LanguageEnum.da: 'da', // 丹麦语
  LanguageEnum.fi: 'fi', // 芬兰语
  LanguageEnum.no: 'no', // 挪威语
  LanguageEnum.sk: 'sk', // 斯洛伐克语
  LanguageEnum.sl: 'sl', // 斯洛文尼亚语
  LanguageEnum.bg: 'bg', // 保加利亚语
  LanguageEnum.af: 'af', // 南非荷兰语
  LanguageEnum.sq: 'sq', // 阿尔巴尼亚语
  LanguageEnum.hy: 'hy', // 亚美尼亚语
  LanguageEnum.az: 'az', // 阿塞拜疆语
  LanguageEnum.eu: 'eu', // 巴斯克语
  LanguageEnum.bn: 'bn', // 孟加拉语
  LanguageEnum.bs: 'bs', // 波斯尼亚语
  LanguageEnum.ca: 'ca', // 加泰罗尼亚语
  LanguageEnum.hr: 'hr', // 克罗地亚语
  LanguageEnum.cy: 'cy', // 威尔士语
  LanguageEnum.et: 'et', // 爱沙尼亚语
  LanguageEnum.tl: 'tl', // 菲律宾语
  LanguageEnum.gl: 'gl', // 加利西亚语
  LanguageEnum.ka: 'ka', // 格鲁吉亚语
  LanguageEnum.gu: 'gu', // 古吉拉特语
  LanguageEnum.ht: 'ht', // 海地克里奥尔语
  LanguageEnum.ha: 'ha', // 豪撒语
  LanguageEnum.haw: 'haw', // 夏威夷语
  LanguageEnum.iw: 'iw', // 希伯来语
  LanguageEnum.jw: 'jw', // 爪哇语
  LanguageEnum.kk: 'kk', // 哈萨克语
  LanguageEnum.km: 'km', // 高棉语
  LanguageEnum.kn: 'kn', // 卡纳达语
  LanguageEnum.ky: 'ky', // 吉尔吉斯语
  LanguageEnum.lo: 'lo', // 老挝语
  LanguageEnum.la: 'la', // 拉丁语
  LanguageEnum.lv: 'lv', // 拉脱维亚语
  LanguageEnum.lt: 'lt', // 立陶宛语
  LanguageEnum.lb: 'lb', // 卢森堡语
  LanguageEnum.mk: 'mk', // 马其顿语
  LanguageEnum.mg: 'mg', // 马尔加什语
  LanguageEnum.mt: 'mt', // 马耳他语
  LanguageEnum.mi: 'mi', // 毛利语
  LanguageEnum.mr: 'mr', // 马拉地语
  LanguageEnum.mn: 'mn', // 蒙古语
  LanguageEnum.ne: 'ne', // 尼泊尔语
  LanguageEnum.ps: 'ps', // 普什图语
  LanguageEnum.pa: 'pa', // 旁遮普语
  LanguageEnum.qu: 'qu', // 克丘亚语
  LanguageEnum.gd: 'gd', // 苏格兰盖尔语
  LanguageEnum.sr: 'sr', // 塞尔维亚语
  LanguageEnum.st: 'st', // 塞索托语
  LanguageEnum.sn: 'sn', // 修纳语
  LanguageEnum.sd: 'sd', // 信德语
  LanguageEnum.si: 'si', // 僧伽罗语
  LanguageEnum.su: 'su', // 巽他语
  LanguageEnum.sw: 'sw', // 斯瓦希里语
  LanguageEnum.tg: 'tg', // 塔吉克语
  LanguageEnum.ta: 'ta', // 泰米尔语
  LanguageEnum.te: 'te', // 泰卢固语
  LanguageEnum.ur: 'ur', // 乌尔都语
  LanguageEnum.uz: 'uz', // 乌兹别克语
  LanguageEnum.xh: 'xh', // 科萨语
  LanguageEnum.yi: 'yi', // 意第绪语
  LanguageEnum.zu: 'zu', // 祖鲁语
};

==> app_service-4.0.0.tar.gz: lib/src/maps/lang_enum_to_string_map.dart <==
import '../enums/language_enum.dart';

/// 语言枚举转字符串映射
/// - 用于获取服务内识别语言的字符串
/// - 此字符串多数情况下为直接可用于 Local 的字符串标识
final Map<LanguageEnum, String> languageEnumToStringMap = {
  LanguageEnum.zh: 'zh', // 中文
  LanguageEnum.zhCN: 'zh-CN', // 简体中文
  LanguageEnum.zhMO: 'zh-MO', // 中文（澳门）
  LanguageEnum.zhHk: 'zh-HK', // 中文（香港）
  LanguageEnum.zhTW: 'zh-TW', // 中文（台湾）
  LanguageEnum.ru: 'ru', // 俄语
  LanguageEnum.ruRU: 'ru-RU', // 俄语
  LanguageEnum.ruBY: 'ru-BY', // 俄语
  LanguageEnum.ruKZ: 'ru-KZ', // 俄语
  LanguageEnum.ruUA: 'ru-UA', // 俄语
  LanguageEnum.uk: 'uk', // 乌克兰
  LanguageEnum.be: 'be', // 白俄罗斯
  LanguageEnum.kk: 'kk', // 哈萨克语
  LanguageEnum.sr: 'sr', // 塞尔维亚
  LanguageEnum.de: 'de', // 德语
  LanguageEnum.fr: 'fr', // 法语
  LanguageEnum.ja: 'ja', // 日语
  LanguageEnum.ko: 'ko', // 韩语
  LanguageEnum.es: 'es', // 西班牙语
  LanguageEnum.ar: 'ar', // 阿拉伯语
  LanguageEnum.en: 'en', // 英语
  LanguageEnum.enUS: 'en-US', // 英语（美国）
  LanguageEnum.enUK: 'en-GB', // 英语（英国）
  LanguageEnum.enAU: 'en-AU', // 英语（澳大利亚）
  LanguageEnum.enIN: 'en-IN', // 英语（印度）
  LanguageEnum.pt: 'pt', // 葡萄牙语
  LanguageEnum.it: 'it', // 意大利语
  LanguageEnum.nl: 'nl', // 荷兰语
  LanguageEnum.tr: 'tr', // 土耳其语
  LanguageEnum.hi: 'hi', // 印地语
  LanguageEnum.id: 'id', // 印度尼西亚语
  LanguageEnum.vi: 'vi', // 越南语
  LanguageEnum.th: 'th', // 泰语
  LanguageEnum.ms: 'ms', // 马来语
  LanguageEnum.fil: 'fil', // 菲律宾语
  LanguageEnum.sv: 'sv', // 瑞典语
  LanguageEnum.pl: 'pl', // 波兰语
  LanguageEnum.hu: 'hu', // 匈牙利语
  LanguageEnum.ro: 'ro', // 罗马尼亚语
  LanguageEnum.cs: 'cs', // 捷克语
  LanguageEnum.el: 'el', // 希腊语
  LanguageEnum.he: 'he', // 希伯来语
  LanguageEnum.da: 'da', // 丹麦语
  LanguageEnum.fi: 'fi', // 芬兰语
  LanguageEnum.no: 'no', // 挪威语
  LanguageEnum.sk: 'sk', // 斯洛伐克语
  LanguageEnum.sl: 'sl', // 斯洛文尼亚语
  LanguageEnum.bg: 'bg', // 保加利亚语
  LanguageEnum.af: 'af', // 南非荷兰语
  LanguageEnum.sq: 'sq', // 阿尔巴尼亚语
  LanguageEnum.hy: 'hy', // 亚美尼亚语
  LanguageEnum.az: 'az', // 阿塞拜疆语
  LanguageEnum.eu: 'eu', // 巴斯克语
  LanguageEnum.bn: 'bn', // 孟加拉语
  LanguageEnum.bs: 'bs', // 波斯尼亚语
  LanguageEnum.ca: 'ca', // 加泰罗尼亚语
  LanguageEnum.hr: 'hr', // 克罗地亚语
  LanguageEnum.cy: 'cy', // 威尔士语
  LanguageEnum.et: 'et', // 爱沙尼亚语
  LanguageEnum.tl: 'tl', // 菲律宾语
  LanguageEnum.gl: 'gl', // 加利西亚语
  LanguageEnum.ka: 'ka', // 格鲁吉亚语
  LanguageEnum.gu: 'gu', // 古吉拉特语
  LanguageEnum.ht: 'ht', // 海地克里奥尔语
  LanguageEnum.ha: 'ha', // 豪撒语
  LanguageEnum.haw: 'haw', // 夏威夷语
  LanguageEnum.iw: 'iw', // 希伯来语
  LanguageEnum.jw: 'jw', // 爪哇语
  LanguageEnum.km: 'km', // 高棉语
  LanguageEnum.kn: 'kn', // 卡纳达语
  LanguageEnum.ky: 'ky', // 吉尔吉斯语
  LanguageEnum.lo: 'lo', // 老挝语
  LanguageEnum.la: 'la', // 拉丁语
  LanguageEnum.lv: 'lv', // 拉脱维亚语
  LanguageEnum.lt: 'lt', // 立陶宛语
  LanguageEnum.lb: 'lb', // 卢森堡语
  LanguageEnum.mk: 'mk', // 马其顿语
  LanguageEnum.mg: 'mg', // 马尔加什语
  LanguageEnum.mt: 'mt', // 马耳他语
  LanguageEnum.mi: 'mi', // 毛利语
  LanguageEnum.mr: 'mr', // 马拉地语
  LanguageEnum.mn: 'mn', // 蒙古语
  LanguageEnum.ne: 'ne', // 尼泊尔语
  LanguageEnum.ps: 'ps', // 普什图语
  LanguageEnum.pa: 'pa', // 旁遮普语
  LanguageEnum.qu: 'qu', // 克丘亚语
  LanguageEnum.gd: 'gd', // 苏格兰盖尔语
  LanguageEnum.st: 'st', // 塞索托语
  LanguageEnum.sn: 'sn', // 修纳语
  LanguageEnum.sd: 'sd', // 信德语
  LanguageEnum.si: 'si', // 僧伽罗语
  LanguageEnum.su: 'su', // 巽他语
  LanguageEnum.sw: 'sw', // 斯瓦希里语
  LanguageEnum.tg: 'tg', // 塔吉克语
  LanguageEnum.ta: 'ta', // 泰米尔语
  LanguageEnum.te: 'te', // 泰卢固语
  LanguageEnum.ur: 'ur', // 乌尔都语
  LanguageEnum.uz: 'uz', // 乌兹别克语
  LanguageEnum.xh: 'xh', // 科萨语
  LanguageEnum.yi: 'yi', // 意第绪语
  LanguageEnum.zu: 'zu', // 祖鲁语
};
